@@ -220,34 +220,56 @@ void DATE_XML(char *xml_filename)
 
   
 
-  MIXT_Check_Model_Validity(mixt_tree);
-  MIXT_Init_Model(mixt_tree);  
-  Print_Data_Structure(NO,stdout,mixt_tree);
-  tree = MIXT_Starting_Tree(mixt_tree);
-  Copy_Tree(tree,mixt_tree);
-  Free_Tree(tree);
-  MIXT_Connect_Cseqs_To_Nodes(mixt_tree);
-  MIXT_Init_T_Beg(mixt_tree);
-  MIXT_Chain_Edges(mixt_tree);
-  MIXT_Chain_Nodes(mixt_tree);
-  MIXT_Make_Tree_For_Pars(mixt_tree);
-  MIXT_Make_Tree_For_Lk(mixt_tree);
-  MIXT_Chain_All(mixt_tree);
-  Add_Root(mixt_tree->a_edges[0],mixt_tree);  
-  MIXT_Check_Edge_Lens_In_All_Elem(mixt_tree);
-  MIXT_Turn_Branches_OnOff_In_All_Elem(ON,mixt_tree);
-  MIXT_Check_Invar_Struct_In_Each_Partition_Elem(mixt_tree);
-  MIXT_Check_RAS_Struct_In_Each_Partition_Elem(mixt_tree);
+  /* MIXT_Check_Model_Validity(mixt_tree); */
+  /* MIXT_Init_Model(mixt_tree);   */
+  /* Print_Data_Structure(NO,stdout,mixt_tree); */
+  /* tree = MIXT_Starting_Tree(mixt_tree); */
+  /* Copy_Tree(tree,mixt_tree); */
+  /* Free_Tree(tree); */
+  /* MIXT_Connect_Cseqs_To_Nodes(mixt_tree); */
+  /* MIXT_Init_T_Beg(mixt_tree); */
+  /* MIXT_Chain_Edges(mixt_tree); */
+  /* MIXT_Chain_Nodes(mixt_tree); */
+  /* MIXT_Make_Tree_For_Pars(mixt_tree); */
+  /* MIXT_Make_Tree_For_Lk(mixt_tree); */
+  /* MIXT_Make_Spr(mixt_tree);   */
+  /* MIXT_Chain_All(mixt_tree); */
+  /* Add_Root(mixt_tree->a_edges[0],mixt_tree);   */
+  /* MIXT_Check_Edge_Lens_In_All_Elem(mixt_tree); */
+  /* MIXT_Turn_Branches_OnOff_In_All_Elem(ON,mixt_tree); */
+  /* MIXT_Check_Invar_Struct_In_Each_Partition_Elem(mixt_tree); */
+  /* MIXT_Check_RAS_Struct_In_Each_Partition_Elem(mixt_tree); */
 
-
-  XML_Read_Calibration(xroot,mixt_tree);
+  /* XML_Read_Calibration(xroot,mixt_tree); */
                           
+  /* MIXT_Chain_Cal(mixt_tree); */
+
   seed = (mixt_tree->io->r_seed < 0)?(time(NULL)):(mixt_tree->io->r_seed);
   srand(seed);
   mixt_tree->io->r_seed = seed;
 
-  MIXT_Chain_Cal(mixt_tree);
 
+  MIXT_Check_Model_Validity(mixt_tree);
+  MIXT_Init_Model(mixt_tree);
+  Print_Data_Structure(NO,stdout,mixt_tree);
+  tree = MIXT_Starting_Tree(mixt_tree);
+  Add_Root(tree->a_edges[0],tree);
+  Copy_Tree(tree,mixt_tree);
+  Free_Tree(tree);
+  MIXT_Connect_Cseqs_To_Nodes(mixt_tree);
+  MIXT_Init_T_Beg(mixt_tree);  
+  MIXT_Make_Tree_For_Lk(mixt_tree);
+  MIXT_Make_Tree_For_Pars(mixt_tree);
+  MIXT_Make_Spr(mixt_tree);  
+  MIXT_Chain_All(mixt_tree);
+  MIXT_Check_Edge_Lens_In_All_Elem(mixt_tree);
+  MIXT_Turn_Branches_OnOff_In_All_Elem(ON,mixt_tree);
+  MIXT_Check_Invar_Struct_In_Each_Partition_Elem(mixt_tree);
+  MIXT_Check_RAS_Struct_In_Each_Partition_Elem(mixt_tree);
+  
+  XML_Read_Calibration(xroot,mixt_tree);
+  MIXT_Chain_Cal(mixt_tree);
+  
   res = DATE_MCMC(mixt_tree);
 
 
@@ -314,7 +336,6 @@ void DATE_Update_T_Prior_MinMax(t_tree *tree)
         {
           for(j=0;j<tree->a_nodes[i]->n_cal;++j)
             {
-              PhyML_Printf("\n. upper: %f lower: %f",tree->a_nodes[i]->cal[j]->upper,tree->a_nodes[i]->cal[j]->lower);
               tree->rates->t_prior_max[i] = MIN(tree->rates->t_prior_max[i],tree->a_nodes[i]->cal[j]->upper);
               tree->rates->t_prior_min[i] = MAX(tree->rates->t_prior_min[i],tree->a_nodes[i]->cal[j]->lower);
             }         
@@ -337,8 +358,11 @@ void DATE_Assign_Primary_Calibration(t_tree *tree)
   for(i=0;i<tree->rates->n_cal;++i)
     {
       cal = tree->rates->a_cal[i];
-      clade = cal->clade_list[cal->current_clade_idx];
-      clade->target_nd = NULL;
+      if(cal->clade_list != NULL)
+        {
+          clade = cal->clade_list[cal->current_clade_idx];
+          clade->target_nd = NULL;
+        }
     }
   
   for(i=0;i<2*tree->n_otu-1;++i) 
@@ -351,26 +375,30 @@ void DATE_Assign_Primary_Calibration(t_tree *tree)
   for(i=0;i<tree->rates->n_cal;++i)
     {
       cal = tree->rates->a_cal[i];
-      clade = cal->clade_list[cal->current_clade_idx];
 
-      node_num = Find_Clade(clade->tax_list,
-                            clade->n_tax,
-                            tree);
-
-      clade->target_nd = tree->a_nodes[node_num];
-      
-      idx = tree->a_nodes[node_num]->n_cal;
-      tree->a_nodes[node_num]->cal[idx] = tree->rates->a_cal[i];
-      tree->a_nodes[node_num]->n_cal++;
-      
-
-      if(tree->a_nodes[node_num]->n_cal == MAX_N_CAL)
+      if(cal->clade_list != NULL)
         {
-          PhyML_Fprintf(stderr,"\n. A node cannot have more than %d calibration",MAX_N_CAL); 
-          PhyML_Fprintf(stderr,"\n. constraints attached to it. Feel free to increase the"); 
-          PhyML_Fprintf(stderr,"\n. value of the variable MAX_N_CAL in utilities.h if");
-          PhyML_Fprintf(stderr,"\n. necessary.");
-          Exit("\n");
+          clade = cal->clade_list[cal->current_clade_idx];
+
+          node_num = Find_Clade(clade->tax_list,
+                                clade->n_tax,
+                                tree);
+
+          clade->target_nd = tree->a_nodes[node_num];
+      
+          idx = tree->a_nodes[node_num]->n_cal;
+          tree->a_nodes[node_num]->cal[idx] = tree->rates->a_cal[i];
+          tree->a_nodes[node_num]->n_cal++;
+      
+
+          if(tree->a_nodes[node_num]->n_cal == MAX_N_CAL)
+            {
+              PhyML_Fprintf(stderr,"\n. A node cannot have more than %d calibration",MAX_N_CAL); 
+              PhyML_Fprintf(stderr,"\n. constraints attached to it. Feel free to increase the"); 
+              PhyML_Fprintf(stderr,"\n. value of the variable MAX_N_CAL in utilities.h if");
+              PhyML_Fprintf(stderr,"\n. necessary.");
+              Exit("\n");
+            }
         }
     }
 }
@@ -696,6 +724,8 @@ phydbl *DATE_MCMC(t_tree *tree)
   if(tree->io->mutmap == YES) Make_MutMap(tree);
   
   TIMES_Randomize_Tree_With_Time_Constraints(tree->rates->a_cal[0],tree);
+  MIXT_Propagate_Tree_Update(tree);
+
   
   mcmc = MCMC_Make_MCMC_Struct();
   tree->mcmc = mcmc;
@@ -766,9 +796,11 @@ phydbl *DATE_MCMC(t_tree *tree)
   RATES_Copy_Rate_Struct(tree->rates,tree->extra_tree->rates,tree->n_otu);
   tree->extra_tree->rates->model = LOGNORMAL;
   RATES_Duplicate_Calib_Struct(tree,tree->extra_tree);
-  MIXT_Chain_Cal(tree->extra_tree);
+  MIXT_Chain_Cal(tree->extra_tree);  
   DATE_Assign_Primary_Calibration(tree->extra_tree);
   TIMES_Randomize_Tree_With_Time_Constraints(tree->extra_tree->rates->a_cal[0],tree->extra_tree);
+  
+  
   TIMES_Lk_Times(NO,tree->extra_tree);
   PhyML_Printf("\n. log(Pr(extra tree)) = %f",tree->extra_tree->rates->c_lnL_times);
   mcmc = MCMC_Make_MCMC_Struct();
@@ -808,7 +840,6 @@ phydbl *DATE_MCMC(t_tree *tree)
       PhyML_Fprintf(fp_stats,"clade(calib:%s)\t",cal->id);
     }
 
-
   
   if(tree->rates->model == THORNE ||
      tree->rates->model == LOGNORMAL ||
@@ -876,7 +907,7 @@ phydbl *DATE_MCMC(t_tree *tree)
       for(move=0;move<tree->mcmc->n_moves;move++) if(tree->mcmc->move_weight[move] > u-1.E-10) break;
       
       assert(!(move == tree->mcmc->n_moves));      
-      
+
       if(!strcmp(tree->mcmc->move_name[move],"clock"))                   MCMC_Clock_R(tree);
       else if(!strcmp(tree->mcmc->move_name[move],"birth_rate"))         MCMC_Birth_Rate(tree);
       else if(!strcmp(tree->mcmc->move_name[move],"death_rate"))         MCMC_Death_Rate(tree);
@@ -900,8 +931,17 @@ phydbl *DATE_MCMC(t_tree *tree)
       else if(!strcmp(tree->mcmc->move_name[move],"clade_change"))       MCMC_Clade_Change(tree);
       else continue;
 
-      /* PhyML_Fprintf(stderr,"\n. move: %s",tree->mcmc->move_name[move]);       */
-                   
+
+      phydbl cur_lk = tree->c_lnL;
+      phydbl new_lk = Lk(NULL,tree);
+      if(Are_Equal(cur_lk,new_lk,1.E-5) == NO)
+        {
+          PhyML_Printf("\n. move: %s",tree->mcmc->move_name[move]);
+          PhyML_Printf("\n. new: %f cur: %f",new_lk,cur_lk);
+          assert(FALSE);
+        }
+
+      
       if(!RATES_Check_Edge_Length_Consistency(tree))
         {
           PhyML_Fprintf(stderr,"\n. Issue detected by RATES_Check_Edge_Length_Consistency(tree).");
@@ -1032,7 +1072,7 @@ phydbl *DATE_MCMC(t_tree *tree)
             }
           
           
-          Time_To_Bl(tree);
+          TIMES_Time_To_Bl(tree);
           tree->bl_ndigits = 3;
           /* RATES_Update_Cur_Bl(tree); */
           s_tree = Write_Tree(tree,NO);
