@@ -1,7 +1,7 @@
 /*
 
-PHYML :  a program that  computes maximum likelihood  phyLOGenies from
-DNA or AA homoLOGous sequences
+PHYML :  a program that  computes maximum likelihood  phylogenies from
+DNA or AA homologous sequences
 
 Copyright (C) Stephane Guindon. Oct 2003 onward
 
@@ -22,7 +22,7 @@ void DR_Draw_Tree(char *file_name, t_tree *tree)
   tree->ps_tree = DR_Make_Tdraw_Struct(tree);
   DR_Init_Tdraw_Struct(tree->ps_tree);
   DR_Get_Tree_Box_Width(tree->ps_tree,tree);
-  Dist_To_Root(tree->n_root,tree);
+  Dist_To_Root(tree);
   tree->ps_tree->max_dist_to_root = DR_Get_Max_Dist_To_Root(tree);
   DR_Get_X_Coord(NO,tree->ps_tree,tree);
   DR_Get_Y_Coord(NO,tree->ps_tree,tree);
@@ -44,7 +44,7 @@ void DR_Get_Tree_Coord(t_tree *tree)
       PhyML_Printf("\n. Adding root before rendering the tree.");
       Add_Root(tree->a_edges[0],tree);
     }
-  Dist_To_Root(tree->n_root,tree);
+  Dist_To_Root(tree);
   tree->ps_tree->max_dist_to_root = DR_Get_Max_Dist_To_Root(tree);
   DR_Get_X_Coord(NO,tree->ps_tree,tree);
   DR_Get_Y_Coord(NO,tree->ps_tree,tree);
@@ -339,7 +339,7 @@ void DR_Print_Tree_Postscript_Pre(t_node *a, t_node *d, t_edge *b, int render_na
       PhyML_Fprintf(fp,"stroke\n");
       PhyML_Fprintf(fp,"gr\n");
       PhyML_Fprintf(fp,"0 0 0 sc\n");
-      For(i,3)
+      for(i=0;i<3;i++)
 	if(d->v[i] != a && d->b[i] != tree->e_root) DR_Print_Tree_Postscript_Pre(d,d->v[i],d->b[i],render_name,fp,w,tree);
     }
 
@@ -362,7 +362,7 @@ void DR_Get_X_Coord_Pre(t_node *a, t_node *d, t_edge *b, tdraw *w, int fixed_tip
   if(d->tax) return;
   else
     {
-      For(i,3)
+      for(i=0;i<3;i++)
 	if((d->v[i] != a) && (d->b[i] != tree->e_root)) 
 	  DR_Get_X_Coord_Pre(d,d->v[i],d->b[i],w,fixed_tips,tree);
     }
@@ -418,7 +418,7 @@ void DR_Get_Y_Coord_Post(t_node *a, t_node *d, t_edge *b, int *next_y_slot, int
       int d1, d2;
 
       d1 = d2 = -1;
-      For(i,3)
+      for(i=0;i<3;i++)
 	{
 	  if(d->v[i] != a && d->b[i] != tree->e_root)
 	    {
@@ -471,7 +471,7 @@ void DR_Get_Tree_Box_Width(tdraw *w, t_tree *tree)
   int max_name_len, curr_len;
 
   max_name_len = curr_len = 0;
-  For(i,tree->n_otu)
+  for(i=0;i<tree->n_otu;i++)
     {
       curr_len = (int)strlen(tree->a_nodes[i]->name);
       if(curr_len > max_name_len) max_name_len = curr_len;
@@ -491,7 +491,7 @@ phydbl DR_Get_Max_Dist_To_Root(t_tree *tree)
   int i;
 
   mx = .0;
-  For(i,tree->n_otu)
+  for(i=0;i<tree->n_otu;i++)
     {
       if(tree->a_nodes[i]->dist_to_root > mx)
 	{
