@@ -70,7 +70,7 @@ int GEO_Estimate(int argc, char **argv)
     
   
   j = 0;
-  For(i,t->ldscape_sz) 
+  for(i=0;i<t->ldscape_sz;i++) 
     {
       t->coord_loc[i]->lonlat[0] = ldscp[j];
       t->coord_loc[i]->lonlat[1] = ldscp[j+1];      
@@ -78,7 +78,7 @@ int GEO_Estimate(int argc, char **argv)
       j+=2;
     }
 
-  For(i,tree->n_otu) t->idx_loc[i] = loc_hash[i];
+  for(i=0;i<tree->n_otu;i++) t->idx_loc[i] = loc_hash[i];
 
   t->cov[0*t->n_dim+0] = t->sigma;
   t->cov[1*t->n_dim+1] = t->sigma;
@@ -96,8 +96,8 @@ int GEO_Estimate(int argc, char **argv)
   probs = (phydbl *)mCalloc(tree->geo->ldscape_sz,sizeof(phydbl));
   
   sum = 0.0;
-  For(i,tree->geo->ldscape_sz) sum += tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i];
-  For(i,tree->geo->ldscape_sz) probs[i] = tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i]/sum;
+  for(i=0;i<tree->geo->ldscape_sz;i++) sum += tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i];
+  for(i=0;i<tree->geo->ldscape_sz;i++) probs[i] = tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i]/sum;
   tree->geo->idx_loc[tree->n_root->num] = Sample_i_With_Proba_pi(probs,tree->geo->ldscape_sz);        
   Free(probs);
 
@@ -181,7 +181,7 @@ int GEO_Simulate_Estimate(int argc, char **argv)
   PhyML_Printf("\n. sigma max: %f threshold: %f",t->max_sigma,t->sigma_thresh);
   
   /* t->tau   = Uni()*(t->max_tau/100.-t->min_tau*10.)  + t->min_tau*10.; */
-  /* t->lbda  = EXP(Uni()*(LOG(t->max_lbda/100.)-LOG(t->min_lbda*10.))  + LOG(t->min_lbda*10.)); */
+  /* t->lbda  = exp(Uni()*(log(t->max_lbda/100.)-log(t->min_lbda*10.))  + log(t->min_lbda*10.)); */
   /* t->sigma = Uni()*(t->max_sigma-t->min_sigma) + t->min_sigma; */
 
   t->lbda  = 1.;
@@ -211,7 +211,7 @@ int GEO_Simulate_Estimate(int argc, char **argv)
   PhyML_Printf("\n. rf: %f",rf);
   
   phydbl scale;
-  scale = EXP(Rnorm(0,0.2));
+  scale = exp(Rnorm(0,0.2));
   PhyML_Printf("\n. Scale: %f",scale);
   For(i,2*tree->n_otu-1) tree->rates->nd_t[i] *= scale;
   
@@ -224,9 +224,9 @@ int GEO_Simulate_Estimate(int argc, char **argv)
   
   geo_dist = (phydbl *)mCalloc(tree->n_otu*tree->n_otu,sizeof(phydbl));
 
-  For(i,tree->n_otu)
+  for(i=0;i<tree->n_otu;i++)
     {
-      For(j,tree->n_otu)
+      for(j=0;j<tree->n_otu;j++)
         {
           /* geo_dist[i*tree->n_otu+j] = */
           /*   FABS(t->ldscape[t->idx_loc[i]*t->n_dim+0] - */
@@ -280,8 +280,8 @@ int GEO_Simulate_Estimate(int argc, char **argv)
   probs = (phydbl *)mCalloc(tree->geo->ldscape_sz,sizeof(phydbl));
   
   sum = 0.0;
-  For(i,tree->geo->ldscape_sz) sum += tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i];
-  For(i,tree->geo->ldscape_sz) probs[i] = tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i]/sum;
+  for(i=0;i<tree->geo->ldscape_sz;i++) sum += tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i];
+  for(i=0;i<tree->geo->ldscape_sz;i++) probs[i] = tree->geo->idx_loc_beneath[tree->n_root->num * tree->geo->ldscape_sz + i]/sum;
   tree->geo->idx_loc[tree->n_root->num] = Sample_i_With_Proba_pi(probs,tree->geo->ldscape_sz);
   Free(probs);
   GEO_Randomize_Locations(tree->n_root,tree->geo,tree);
@@ -356,7 +356,6 @@ phydbl *GEO_MCMC(t_tree *tree)
 
   tree->mcmc->io               = NULL;
   tree->mcmc->is               = NO;
-  tree->mcmc->use_data         = YES;
   tree->mcmc->run              = 0;
   tree->mcmc->sample_interval  = 1E+3;
   tree->mcmc->chain_len        = 1E+6;
@@ -517,9 +516,9 @@ void GEO_Update_Fmat(t_geo *t)
   int err;
   phydbl lognloc;
   
-  For(i,t->n_dim) t->cov[i*t->n_dim+i] = t->sigma; // Diagonal covariance matrix. Same variance in every direction
+  for(i=0;i<t->n_dim;i++) t->cov[i*t->n_dim+i] = t->sigma; // Diagonal covariance matrix. Same variance in every direction
 
-  lognloc = LOG(t->ldscape_sz);
+  lognloc = log(t->ldscape_sz);
 
   // Fill in F matrix;
   for(i=0;i<t->ldscape_sz;i++)
@@ -533,12 +532,12 @@ void GEO_Update_Fmat(t_geo *t)
           t->f_mat[i*t->ldscape_sz+j] = .0;
 
           // Calculate log(f(l_i,l_j)) - log(f(l_i,l_i) - log(m) 
-          For(k,t->n_dim) t->f_mat[i*t->ldscape_sz+j] += Log_Dnorm(loc2[k],loc1[k],t->cov[k*t->n_dim+k],&err);
+          for(k=0;k<t->n_dim;k++) t->f_mat[i*t->ldscape_sz+j] += Log_Dnorm(loc2[k],loc1[k],t->cov[k*t->n_dim+k],&err);
           t->f_mat[i*t->ldscape_sz+j] -= lognloc;
-          For(k,t->n_dim) t->f_mat[i*t->ldscape_sz+j] -= Log_Dnorm(loc1[k],loc1[k],t->cov[k*t->n_dim+k],&err);
+          for(k=0;k<t->n_dim;k++) t->f_mat[i*t->ldscape_sz+j] -= Log_Dnorm(loc1[k],loc1[k],t->cov[k*t->n_dim+k],&err);
 
           // Take the exponential
-          t->f_mat[i*t->ldscape_sz+j] = EXP(t->f_mat[i*t->ldscape_sz+j]);
+          t->f_mat[i*t->ldscape_sz+j] = exp(t->f_mat[i*t->ldscape_sz+j]);
           
           // Matrix is symmetric
           t->f_mat[j*t->ldscape_sz+i] = t->f_mat[i*t->ldscape_sz+j];
@@ -598,7 +597,7 @@ void GEO_Update_Occup(t_geo *t, t_tree *tree)
   
   for(i=1;i<2*tree->n_otu-1;i++)
     {
-      For(j,t->ldscape_sz) 
+      for(j=0;j<t->ldscape_sz;j++) 
         {
           t->occup[t->sorted_nd[i]->num*t->ldscape_sz + j] = 
             t->occup[t->sorted_nd[i-1]->num*t->ldscape_sz + j];
@@ -615,7 +614,7 @@ void GEO_Update_Occup(t_geo *t, t_tree *tree)
             }
           else
             {
-              For(j,3)
+              for(j=0;j<3;j++)
                 {
                   if(t->sorted_nd[i-1]->v[j] != t->sorted_nd[i-1]->anc &&
                      t->sorted_nd[i-1]->b[j] != tree->e_root)
@@ -642,7 +641,7 @@ void GEO_Update_Occup(t_geo *t, t_tree *tree)
   /* For(i,2*tree->n_otu-1) */
   /*   { */
   /*     printf("\n. Node %3d: ",t->sorted_nd[i]->num); */
-  /*     For(j,t->ldscape_sz) */
+  /*     for(j=0;j<t->ldscape_sz;j++) */
   /*       { */
   /*         /\* printf("%3d [%12f;%12f]   ", *\/ */
   /*         /\*        t->occup[t->sorted_nd[i]->num*t->ldscape_sz + j], *\/ */
@@ -662,9 +661,9 @@ void GEO_Update_Rmat(t_node *n, t_geo *t, t_tree *tree)
   int i,j;
   phydbl lbda_j;
 
-  For(i,t->ldscape_sz)
+  for(i=0;i<t->ldscape_sz;i++)
     {
-      For(j,t->ldscape_sz)
+      for(j=0;j<t->ldscape_sz;j++)
         {
           lbda_j = ((t->occup[n->num*t->ldscape_sz + j]==0) ? (1.0) : (t->lbda));
           t->r_mat[i*t->ldscape_sz+j] = t->f_mat[i*t->ldscape_sz+j] * lbda_j * t->tau * t->dum;          
@@ -722,7 +721,7 @@ phydbl GEO_Lk(t_geo *t, t_tree *tree)
           
       /*     printf("\n >> "); */
       /*     int j; */
-      /*     For(j,t->ldscape_sz)  */
+      /*     for(j=0;j<t->ldscape_sz;j++)  */
       /*       if(t->occup[t->sorted_nd[i]->num * t->ldscape_sz + j] > 0)  */
       /*         printf("%f %f -- ", */
       /*                t->ldscape[j*t->n_dim+0], */
@@ -733,7 +732,7 @@ phydbl GEO_Lk(t_geo *t, t_tree *tree)
       /* printf("\n. %d %d (%d) %f %p %p \n",i,curr_n->num,curr_n->tax,tree->rates->nd_t[curr_n->num],curr_n->v[1],curr_n->v[2]); */
 
       v1 = v2 = NULL;
-      For(j,3) 
+      for(j=0;j<3;j++) 
         if(curr_n->v[j] != curr_n->anc && curr_n->b[j] != tree->e_root)
           {
             if(!v1) v1 = curr_n->v[j];
@@ -751,12 +750,12 @@ phydbl GEO_Lk(t_geo *t, t_tree *tree)
       /*        t->ldscape[arr*t->n_dim+1]-t->ldscape[dep*t->n_dim+1]); */
 
       loglk -= R * FABS(tree->rates->nd_t[curr_n->num] - tree->rates->nd_t[prev_n->num]);
-      loglk += LOG(t->r_mat[dep * t->ldscape_sz + arr]);
+      loglk += log(t->r_mat[dep * t->ldscape_sz + arr]);
 
       /* printf("\n <> %d %f %f %d %d v1:%d v2:%d anc:%d %d %d %d", */
       /*        curr_n->num, */
       /*        R * FABS(tree->rates->nd_t[curr_n->num] - tree->rates->nd_t[prev_n->num]), */
-      /*        LOG(t->r_mat[dep * t->ldscape_sz + arr]), */
+      /*        log(t->r_mat[dep * t->ldscape_sz + arr]), */
       /*        dep,arr,v1->num,v2->num,curr_n->anc->num,curr_n->v[0]->num,curr_n->v[1]->num,curr_n->v[2]->num); */
 
       /* if(i<2) */
@@ -776,7 +775,7 @@ phydbl GEO_Lk(t_geo *t, t_tree *tree)
   // the next node)
   GEO_Update_Rmat(tree->n_root,t,tree);
 
-  loglk -= LOG(t->ldscape_sz); 
+  loglk -= log(t->ldscape_sz); 
   dep = t->idx_loc[tree->n_root->num];
   arr = 
     (t->idx_loc[tree->n_root->num] != t->idx_loc[tree->n_root->v[1]->num] ? 
@@ -785,12 +784,12 @@ phydbl GEO_Lk(t_geo *t, t_tree *tree)
   
   /* printf("\n %f %f",t->ldscape[dep],t->ldscape[arr]); */
 
-  loglk += LOG(t->r_mat[dep * t->ldscape_sz + arr]);
+  loglk += log(t->r_mat[dep * t->ldscape_sz + arr]);
     
   sum = .0;
-  For(i,t->ldscape_sz) sum += t->r_mat[dep * t->ldscape_sz + i];
+  for(i=0;i<t->ldscape_sz;i++) sum += t->r_mat[dep * t->ldscape_sz + i];
   
-  loglk -= LOG(sum);
+  loglk -= log(sum);
 
   tree->geo->c_lnL = loglk;
 
@@ -805,7 +804,7 @@ void GEO_Init_Tloc_Tips(t_geo *t, t_tree *tree)
   int i;
 
   // TO DO
-  For(i,tree->n_otu)
+  for(i=0;i<tree->n_otu;i++)
     {
       t->idx_loc[i] = i;
     }
@@ -822,9 +821,9 @@ phydbl GEO_Total_Migration_Rate(t_node *n, t_geo *t)
 
   R = .0;
 
-  For(i,t->ldscape_sz)
+  for(i=0;i<t->ldscape_sz;i++)
     {
-      For(j,t->ldscape_sz)
+      for(j=0;j<t->ldscape_sz;j++)
         {
           R += 
             t->r_mat[i * t->ldscape_sz + j] * 
@@ -846,7 +845,7 @@ int GEO_Get_Arrival_Location(t_node *n, t_geo *t, t_tree *tree)
 
   v1 = v2 = NULL;
 
-  For(i,3)
+  for(i=0;i<3;i++)
     {
       if(n->v[i] && n->v[i] != n->anc)
         {
@@ -943,7 +942,7 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
 
  // total migration rate
   R = 0.0;
-  For(i,t->ldscape_sz) 
+  for(i=0;i<t->ldscape_sz;i++) 
     {
       R += 
         t->f_mat[t->idx_loc[tree->n_root->num]*t->ldscape_sz+i] * 
@@ -968,7 +967,7 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
       dep = t->idx_loc[branching_nodes[hit]->num]; // Departure point
            
       sum = .0;
-      For(i,t->ldscape_sz) // Total rate of migration out of departure point
+      for(i=0;i<t->ldscape_sz;i++) // Total rate of migration out of departure point
         {
           p_mig[i] = 
             t->f_mat[dep*t->ldscape_sz+i] * 
@@ -977,7 +976,7 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
 
           sum += p_mig[i];
         }      
-      For(i,t->ldscape_sz) p_mig[i] /= sum;
+      for(i=0;i<t->ldscape_sz;i++) p_mig[i] /= sum;
 
       arr = Sample_i_With_Proba_pi(p_mig,t->ldscape_sz);
 
@@ -1014,11 +1013,11 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
 
       // Update total migration rate 
       R = .0;
-      For(i,t->ldscape_sz)
+      for(i=0;i<t->ldscape_sz;i++)
         {
           if(occup[i] > 0)
             {
-              For(j,t->ldscape_sz)
+              for(j=0;j<t->ldscape_sz;j++)
                 {
                   R += 
                     occup[i] *
@@ -1037,7 +1036,7 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
         {
           dep = t->idx_loc[branching_nodes[i]->num];
           p_branch[i] = 0.0;
-          For(j,t->ldscape_sz)
+          for(j=0;j<t->ldscape_sz;j++)
             {
               p_branch[i] +=
                 t->f_mat[dep*t->ldscape_sz+j] * 
@@ -1119,7 +1118,7 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
     /* } */
 
 
-  For(i,tree->n_otu) 
+  for(i=0;i<tree->n_otu;i++) 
     {
       if(!tree->a_nodes[i]->name) tree->a_nodes[i]->name = (char *)mCalloc(T_MAX_NAME,sizeof(char));
       strcpy(tree->a_nodes[i]->name,"x");
@@ -1160,7 +1159,7 @@ t_tree *GEO_Simulate(t_geo *t, int n_otu)
 
   DR_Draw_Tree("essai.ps",tree);
 
-  /* For(i,tree->n_otu) */
+  /* for(i=0;i<tree->n_otu;i++) */
   /*   printf("\n. %4s %4d [%5.2f %5.2f]",tree->a_nodes[i]->name, */
   /*          t->idx_loc[i], */
   /*          t->ldscape[t->idx_loc[i]*t->n_dim+0], */
@@ -1188,7 +1187,7 @@ void GEO_Simulate_Coordinates(int n, t_geo *t)
 
   width = 5.;
 
-  For(i,n)
+  for(i=0;i<n;i++)
     {
       /* t->ldscape[i*t->n_dim+0] = -width/2. + Uni()*width; */
       /* t->ldscape[i*t->n_dim+1] = width/2.; */
@@ -1302,7 +1301,7 @@ void GEO_Randomize_Locations(t_node *n, t_geo *t, t_tree *tree)
       probs = (phydbl *)mCalloc(t->ldscape_sz,sizeof(phydbl));
       
       v1 = v2 = NULL;
-      For(i,3)
+      for(i=0;i<3;i++)
         {
           if(n->v[i] != n->anc && n->b[i] != tree->e_root)
             {
@@ -1327,16 +1326,16 @@ void GEO_Randomize_Locations(t_node *n, t_geo *t, t_tree *tree)
       else if(v1->tax && !v2->tax && t->idx_loc[v1->num] == t->idx_loc[n->num])
         {
           sum = 0.0;
-          For(i,t->ldscape_sz) sum += t->idx_loc_beneath[v2->num * t->ldscape_sz + i];
-          For(i,t->ldscape_sz) probs[i] = t->idx_loc_beneath[v2->num * t->ldscape_sz + i]/sum;
+          for(i=0;i<t->ldscape_sz;i++) sum += t->idx_loc_beneath[v2->num * t->ldscape_sz + i];
+          for(i=0;i<t->ldscape_sz;i++) probs[i] = t->idx_loc_beneath[v2->num * t->ldscape_sz + i]/sum;
           
           t->idx_loc[v2->num] = Sample_i_With_Proba_pi(probs,t->ldscape_sz);      
         }
       else if(v2->tax && !v1->tax && t->idx_loc[v2->num] == t->idx_loc[n->num])
         {
           sum = 0.0;
-          For(i,t->ldscape_sz) sum += t->idx_loc_beneath[v1->num * t->ldscape_sz + i];
-          For(i,t->ldscape_sz) probs[i] = t->idx_loc_beneath[v1->num * t->ldscape_sz + i]/sum;
+          for(i=0;i<t->ldscape_sz;i++) sum += t->idx_loc_beneath[v1->num * t->ldscape_sz + i];
+          for(i=0;i<t->ldscape_sz;i++) probs[i] = t->idx_loc_beneath[v1->num * t->ldscape_sz + i]/sum;
           
           t->idx_loc[v1->num] = Sample_i_With_Proba_pi(probs,t->ldscape_sz);      
         }
@@ -1362,8 +1361,8 @@ void GEO_Randomize_Locations(t_node *n, t_geo *t, t_tree *tree)
           if(u < p)
             {              
               sum = 0.0;
-              For(i,t->ldscape_sz) sum += t->idx_loc_beneath[v2->num * t->ldscape_sz + i];
-              For(i,t->ldscape_sz) probs[i] = t->idx_loc_beneath[v2->num * t->ldscape_sz + i]/sum;
+              for(i=0;i<t->ldscape_sz;i++) sum += t->idx_loc_beneath[v2->num * t->ldscape_sz + i];
+              for(i=0;i<t->ldscape_sz;i++) probs[i] = t->idx_loc_beneath[v2->num * t->ldscape_sz + i]/sum;
               
               t->idx_loc[v2->num] = Sample_i_With_Proba_pi(probs,t->ldscape_sz);      
               t->idx_loc[v1->num] = t->idx_loc[n->num];                
@@ -1373,8 +1372,8 @@ void GEO_Randomize_Locations(t_node *n, t_geo *t, t_tree *tree)
               if(t->idx_loc_beneath[v2->num * t->ldscape_sz + t->idx_loc[n->num]] > 0)
                 {
                   sum = 0.0;
-                  For(i,t->ldscape_sz) sum += t->idx_loc_beneath[v1->num * t->ldscape_sz + i];
-                  For(i,t->ldscape_sz) probs[i] = t->idx_loc_beneath[v1->num * t->ldscape_sz + i]/sum;
+                  for(i=0;i<t->ldscape_sz;i++) sum += t->idx_loc_beneath[v1->num * t->ldscape_sz + i];
+                  for(i=0;i<t->ldscape_sz;i++) probs[i] = t->idx_loc_beneath[v1->num * t->ldscape_sz + i]/sum;
                   
                   t->idx_loc[v1->num] = Sample_i_With_Proba_pi(probs,t->ldscape_sz);      
                   t->idx_loc[v2->num] = t->idx_loc[n->num];
@@ -1382,8 +1381,8 @@ void GEO_Randomize_Locations(t_node *n, t_geo *t, t_tree *tree)
               else
                 {
                   sum = 0.0;
-                  For(i,t->ldscape_sz) sum += t->idx_loc_beneath[v2->num * t->ldscape_sz + i];
-                  For(i,t->ldscape_sz) probs[i] = t->idx_loc_beneath[v2->num * t->ldscape_sz + i]/sum;
+                  for(i=0;i<t->ldscape_sz;i++) sum += t->idx_loc_beneath[v2->num * t->ldscape_sz + i];
+                  for(i=0;i<t->ldscape_sz;i++) probs[i] = t->idx_loc_beneath[v2->num * t->ldscape_sz + i]/sum;
                   
                   t->idx_loc[v2->num] = Sample_i_With_Proba_pi(probs,t->ldscape_sz);      
                   t->idx_loc[v1->num] = t->idx_loc[n->num];                
@@ -1415,7 +1414,7 @@ void GEO_Randomize_Locations(t_node *n, t_geo *t, t_tree *tree)
       
       Free(probs);
       
-      For(i,3)
+      for(i=0;i<3;i++)
         if(n->v[i] != n->anc && n->b[i] != tree->e_root) 
           GEO_Randomize_Locations(n->v[i],t,tree);
     }
@@ -1430,7 +1429,7 @@ void GEO_Get_Locations_Beneath(t_geo *t, t_tree *tree)
   GEO_Get_Locations_Beneath_Post(tree->n_root,tree->n_root->v[1],t,tree);
   GEO_Get_Locations_Beneath_Post(tree->n_root,tree->n_root->v[2],t,tree);
 
-  For(i,t->ldscape_sz)
+  for(i=0;i<t->ldscape_sz;i++)
     {
       t->idx_loc_beneath[tree->n_root->num*t->ldscape_sz+i] =
         t->idx_loc_beneath[tree->n_root->v[1]->num*t->ldscape_sz+i] +
@@ -1454,7 +1453,7 @@ void GEO_Get_Locations_Beneath_Post(t_node *a, t_node *d, t_geo *t, t_tree *tree
       int i;
       t_node *v1, *v2;
 
-      For(i,3) 
+      for(i=0;i<3;i++) 
         {
           if(d->v[i] != a && d->b[i] != tree->e_root)
             {
@@ -1464,7 +1463,7 @@ void GEO_Get_Locations_Beneath_Post(t_node *a, t_node *d, t_geo *t, t_tree *tree
           
 
       v1 = v2 = NULL;
-      For(i,3) 
+      for(i=0;i<3;i++) 
         {
           if(d->v[i] != a && d->b[i] != tree->e_root)
             {
@@ -1474,7 +1473,7 @@ void GEO_Get_Locations_Beneath_Post(t_node *a, t_node *d, t_geo *t, t_tree *tree
         }
           
 
-      For(i,t->ldscape_sz) 
+      for(i=0;i<t->ldscape_sz;i++) 
         {
           t->idx_loc_beneath[ d->num*t->ldscape_sz+i] = 
             t->idx_loc_beneath[v1->num*t->ldscape_sz+i] + 
@@ -1503,7 +1502,7 @@ void GEO_Get_Sigma_Max(t_geo *t)
 
   mean_dist = -1.;
   inv_mean_dist = -1.;
-  For(i,t->ldscape_sz-1)
+  for(i=0;i<t->ldscape_sz-1;i++)
     {
       for(j=i+1;j<t->ldscape_sz;j++)
         {
@@ -1612,7 +1611,7 @@ void MCMC_Geo_Updown_Tau_Lbda(t_tree *tree)
   new_lbda = tree->geo->lbda;
 
   u = Uni();
-  mult = EXP(K*(u-0.5));
+  mult = exp(K*(u-0.5));
 
   /* Multiply tau by K */
   new_tau = cur_tau * K;
@@ -1633,18 +1632,18 @@ void MCMC_Geo_Updown_Tau_Lbda(t_tree *tree)
   tree->geo->tau  = new_tau;
   tree->geo->lbda = new_lbda;
 
-  if(tree->mcmc->use_data) new_lnL = GEO_Lk(tree->geo,tree);
+  if(tree->eval_alnL) new_lnL = GEO_Lk(tree->geo,tree);
 
   ratio = 0.0;
   /* Proposal ratio: 2n-2=> number of multiplications, 1=>number of divisions */
-  ratio += 0.0*LOG(mult); /* (1-1)*LOG(mult); */
+  ratio += 0.0*log(mult); /* (1-1)*log(mult); */
   /* Likelihood density ratio */
   ratio += (new_lnL - cur_lnL);
 
   /* printf("\n. new_tau: %f new_lbda:%f cur_lnL:%f new_lnL:%f",new_tau,new_lbda,cur_lnL,new_lnL); */
 
 
-  ratio = EXP(ratio);
+  ratio = exp(ratio);
   alpha = MIN(1.,ratio);
   u = Uni();
   
@@ -1682,7 +1681,7 @@ void MCMC_Geo_Updown_Lbda_Sigma(t_tree *tree)
   new_sigma = tree->geo->sigma;
 
   u = Uni();
-  mult = EXP(K*(u-0.5));
+  mult = exp(K*(u-0.5));
 
   /* Multiply lbda by K */
   new_lbda = cur_lbda * K;
@@ -1703,18 +1702,18 @@ void MCMC_Geo_Updown_Lbda_Sigma(t_tree *tree)
   tree->geo->lbda   = new_lbda;
   tree->geo->sigma = new_sigma;
 
-  if(tree->mcmc->use_data) new_lnL = GEO_Lk(tree->geo,tree);
+  if(tree->eval_alnL) new_lnL = GEO_Lk(tree->geo,tree);
 
   ratio = 0.0;
   /* Proposal ratio: 2n-2=> number of multiplications, 1=>number of divisions */
-  ratio += 0.0*LOG(mult); /* (1-1)*LOG(mult); */
+  ratio += 0.0*log(mult); /* (1-1)*log(mult); */
   /* Likelihood density ratio */
   ratio += (new_lnL - cur_lnL);
 
   /* printf("\n. new_lbda: %f new_sigma:%f cur_lnL:%f new_lnL:%f",new_lbda,new_sigma,cur_lnL,new_lnL); */
 
 
-  ratio = EXP(ratio);
+  ratio = exp(ratio);
   alpha = MIN(1.,ratio);
   u = Uni();
   
@@ -1759,7 +1758,7 @@ void GEO_Read_In_Landscape(char *file_name, t_geo *t, phydbl **ldscape, int **lo
     {
       if(fscanf(fp,"%s",s) == EOF) break;
 
-      if(strlen(s) > 0) For(tax,tree->n_otu) if(!strcmp(tree->a_nodes[tax]->name,s)) break;
+      if(strlen(s) > 0) for(tax=0;tax<tree->n_otu;tax++) if(!strcmp(tree->a_nodes[tax]->name,s)) break;
 
       if(tax == tree->n_otu)
         {
@@ -1775,7 +1774,7 @@ void GEO_Read_In_Landscape(char *file_name, t_geo *t, phydbl **ldscape, int **lo
 
       /* printf("\n. s: %s %f %f",s,longitude,lattitude); */
 
-      For(loc,t->ldscape_sz)
+      for(loc=0;loc<t->ldscape_sz;loc++)
         {
           if(FABS(longitude-(*ldscape)[loc*t->n_dim+0]) < 1.E-10 &&
              FABS(lattitude-(*ldscape)[loc*t->n_dim+1]) < 1.E-10)
@@ -1801,7 +1800,7 @@ void GEO_Read_In_Landscape(char *file_name, t_geo *t, phydbl **ldscape, int **lo
     }
   while(1);
 
-  For(tax,tree->n_otu)
+  for(tax=0;tax<tree->n_otu;tax++)
     PhyML_Printf("\n. Taxon %30s, longitude: %12f, lattitude: %12f [%4d]",
                  tree->a_nodes[tax]->name,
                  (*ldscape)[(*loc_hash)[tax]*t->n_dim+0],
