@@ -182,6 +182,7 @@ int main(int argc, char **argv)
                       if(tree->has_branch_lengths == NO) Add_BioNJ_Branch_Lengths(tree,cdata,mod,NULL);
                     }
 
+                  
                   if(!tree) continue;
                   
                   time(&t_beg);
@@ -263,9 +264,8 @@ int main(int argc, char **argv)
                   Lk(NULL,tree);
                   Pars(NULL,tree);
                   Get_Tree_Size(tree);
-                  PhyML_Printf("\n\n. Log likelihood of the current tree: %f.",tree->c_lnL);
+                  PhyML_Printf("\n\n. Log likelihood of the current tree: %.*f.",DECIMAL_DIG,tree->c_lnL);
 
-                  
                   if(tree->io->ancestral == YES) Ancestral_Sequences(tree,YES);
                   
                   Check_Br_Lens(tree);
@@ -585,28 +585,26 @@ int main(int argc, char **argv)
 #include "xml.h"
 int main(int argc, char **argv)
 {
-  option *io = Get_Input(argc,argv);
-  char *s = (char *)mCalloc(5,sizeof(char));
+  option *io;
   int i;
   
+  io = (option *)Get_Input(argc,argv);
+  if(!io) return(0);
+
   Get_Seq(io);
-  
-  for(i=0;i<io->n_otu;++i)
-    {      
-      PhyML_Printf("\n\n\n");
+
+  for(i=0;i<io->n_otu;i++)
+    {
       PhyML_Printf("\n<clade id=\"clad%d\">",i+1);
-      PhyML_Printf("\n<taxon value=\"%s\"/>",io->data[i]->name);
+      PhyML_Printf("\n\t<taxon value=\"%s\"/>",io->data[i]->name);
       PhyML_Printf("\n</clade>");
-      PhyML_Printf("\n");
       PhyML_Printf("\n<calibration id=\"cal%d\">",i+1);
-      strncpy(s,io->data[i]->name,4);
-      s[4]='\0';
-      PhyML_Printf("\n<lower>%d</lower>",atoi(s)-2017);
-      PhyML_Printf("\n<upper>%d</upper>",atoi(s)-2017);
-      PhyML_Printf("\n<appliesto clade.id=\"clad%d\"/>",i+1);
+      PhyML_Printf("\n\t<lower>0.0</lower>");
+      PhyML_Printf("\n\t<upper>0.0</upper>");
+      PhyML_Printf("\n\t<appliesto clade.id=\"clad%d\"/>",i+1);
       PhyML_Printf("\n</calibration>");
     }
-
+  
 }
 
 #elif(INVITEE)
