@@ -745,13 +745,13 @@ void Global_Spr_Search(t_tree *tree)
   
   best_lnL      = UNLIKELY;
   tree->verbose = (tree->verbose == VL0) ? VL0 : VL1;
-  best_tree     = Make_Tree_From_Scratch(tree->n_otu,tree->data);
+  best_tree     = Duplicate_Tree(tree);
     
   if(tree->io->print_json_trace == YES) JSON_Tree_Io(tree,tree->io->fp_out_json_trace);
 
   if(tree->verbose > VL0 && tree->io->quiet == NO) PhyML_Printf("\n\n. Score of initial tree: %.2f",tree->c_lnL);
 
-
+                 
   tree->mod->s_opt->min_diff_lk_move  = 1.E-1;
   tree->mod->s_opt->min_diff_lk_local = 1.E-1;
   Round_Optimize(tree,1000);
@@ -801,7 +801,7 @@ void Global_Spr_Search(t_tree *tree)
       if(tree->verbose > VL0 && tree->io->quiet == NO)
         {
           time(&t_cur);
-          PhyML_Printf("\n\t%8ds | %3d | lnL=%12.1f | depth=%5d/%5d | improvements=%4d | delta_lnL=%7.1f/%7.1f | tune=%.2f",
+          PhyML_Printf("\n\t%8ds | %3d | lnL=%12.1f | depth=%5d/%5d | improvements=%4d | delta_lnL=%7.1f/%7.1f %c",
                        (int)(t_cur-tree->t_beg),
                        iter+1,
                        tree->c_lnL,
@@ -810,7 +810,7 @@ void Global_Spr_Search(t_tree *tree)
                        tree->mod->s_opt->n_improvements,
                        tree->mod->s_opt->max_delta_lnL_spr_current,
                        tree->mod->s_opt->max_delta_lnL_spr,
-                       tune_l_mult);
+                       (tree->numerical_warning == YES) ? '!' : ' ');
         }
 
       if(tree->mod->s_opt->n_improvements > (int)(tree->n_otu/5))
@@ -894,7 +894,7 @@ void Global_Spr_Search(t_tree *tree)
       if(tree->verbose > VL0 && tree->io->quiet == NO)
         {
           time(&t_cur);
-          PhyML_Printf("\n\t%8ds | %3d | lnL=%12.1f | depth=%5d/%5d | improvements=%4d | delta_lnL=%7.1f/%7.1f",
+          PhyML_Printf("\n\t%8ds | %3d | lnL=%12.1f | depth=%5d/%5d | improvements=%4d | delta_lnL=%7.1f/%7.1f %c",
                        (int)(t_cur-tree->t_beg),
                        iter+1,
                        tree->c_lnL,
@@ -902,7 +902,8 @@ void Global_Spr_Search(t_tree *tree)
                        tree->mod->s_opt->max_depth_path,
                        tree->mod->s_opt->n_improvements,
                        tree->mod->s_opt->max_delta_lnL_spr_current,
-                       tree->mod->s_opt->max_delta_lnL_spr);
+                       tree->mod->s_opt->max_delta_lnL_spr,
+                       (tree->numerical_warning == YES) ? '!' : ' ');
         }
 
       tree->mod->s_opt->max_depth_path = MAX(5,MAX(tree->mod->s_opt->max_spr_depth+4,(int)(0.8*tree->mod->s_opt->max_depth_path)));
@@ -969,7 +970,7 @@ void Global_Spr_Search(t_tree *tree)
       if(tree->verbose > VL0 && tree->io->quiet == NO)
         {
           time(&t_cur);
-          PhyML_Printf("\n\t%8ds | %3d | lnL=%12.1f | depth=%5d/%5d | improvements=%4d | delta_lnL=%7.1f/%7.1f | triple moves=%4d",
+          PhyML_Printf("\n\t%8ds | %3d | lnL=%12.1f | depth=%5d/%5d | improvements=%4d | delta_lnL=%7.1f/%7.1f | triple moves=%4d %c",
                        (int)(t_cur-tree->t_beg),
                        iter+1,
                        tree->c_lnL,
@@ -978,7 +979,8 @@ void Global_Spr_Search(t_tree *tree)
                        tree->mod->s_opt->n_improvements,
                        tree->mod->s_opt->max_delta_lnL_spr_current,
                        tree->mod->s_opt->max_delta_lnL_spr,
-                       tree->mod->s_opt->min_n_triple_moves);
+                       tree->mod->s_opt->min_n_triple_moves,
+                       (tree->numerical_warning == YES) ? '!' : ' ');
         }
       
       tree->mod->s_opt->max_depth_path     = MIN(30,MAX(5,MAX(2*tree->mod->s_opt->max_spr_depth,(int)(0.8*tree->mod->s_opt->max_depth_path))));
@@ -998,11 +1000,11 @@ void Global_Spr_Search(t_tree *tree)
       iter++;
     }
   while(tree->mod->s_opt->n_improvements > 0 && last_best_found <= tree->mod->s_opt->max_no_better_tree_found);
-  
+
   Copy_Tree(best_tree,tree);
   
   if(tree->verbose > VL0 && tree->io->quiet == NO) PhyML_Printf("\n\n. Final optimisation steps...\n");
-
+  
   i = tree->verbose;
   tree->verbose = VL0;
   tree->mod->s_opt->min_diff_lk_move  = 1.E-03;
@@ -1016,7 +1018,6 @@ void Global_Spr_Search(t_tree *tree)
   while(1);
   tree->verbose = i;
   
-
   Free_Tree(best_tree);
 
   return;
@@ -1123,8 +1124,8 @@ void Speed_Spr(t_tree *tree, phydbl prop_spr, int max_cycles, phydbl delta_lnL)
 
       /* Exit if no improvements after complete optimization */
       if(step+1 > max_cycles) break;
-      if((tree->mod->s_opt->spr_pars == NO)  && (FABS(old_lnL-tree->c_lnL)   < delta_lnL)) break;
-      if((tree->mod->s_opt->spr_pars == YES) && (FABS(old_pars-tree->c_pars) < 1)) break;
+      if((tree->mod->s_opt->spr_pars == NO)  && (fabs(old_lnL-tree->c_lnL)   < delta_lnL)) break;
+      if((tree->mod->s_opt->spr_pars == YES) && (fabs((phydbl)(old_pars-tree->c_pars)) < 1)) break;
       if(!tree->mod->s_opt->n_improvements) break;
     }
   while(1);
@@ -1197,7 +1198,7 @@ int Evaluate_List_Of_Regraft_Pos_Triple(t_spr **spr_list, int list_size, t_tree
                */
               recorded = YES;
               
-              Br_Len_Opt(init_target,tree);
+              Br_Len_Opt(&(init_target->l->v),init_target,tree);
 
               /*! Record branch length at prune site */
               if(recorded_l == NULL)
@@ -1806,7 +1807,7 @@ void Spr_Pars(int threshold, int n_round_max, t_tree *tree)
       curr_pars = tree->c_pars;
       Speed_Spr(tree,1.0,1,0.0);      
     }
-  while(tree->mod->s_opt->n_improvements && FABS(tree->c_pars - curr_pars) > threshold && round++ < n_round_max);
+  while(tree->mod->s_opt->n_improvements && fabs((phydbl)(tree->c_pars - curr_pars)) > threshold && round++ < n_round_max);
 }
 
 //////////////////////////////////////////////////////////////
