@@ -42,6 +42,10 @@ the GNU public licence. See http://www.opensource.org for details.
 #endif
 
 
+#if !defined(__FMA__) && defined(__AVX2__)
+    #define __FMA__ 1
+#endif
+
 extern int n_sec1;
 extern int n_sec2;
 
@@ -718,6 +722,7 @@ typedef struct __Tree{
   struct __Phylogeo                      *geo;
   struct __Migrep_Model                 *mmod;
   struct __Disk_Event             *young_disk; /*! Youngest disk (i.e., disk which age is the closest to present). Used in PhyREX */
+  struct __Disk_Event          *old_samp_disk; /*! Oldest sampled disk. Used in PhyREX */
   struct __XML_node                 *xml_root;
   struct __Generic_LL              *edge_list;
   struct __Generic_LL              *node_list;
@@ -824,6 +829,7 @@ typedef struct __Tree{
   phydbl                                   *K; /*! a vector of the norm.constants for the node times prior. */
 
   short int                       ignore_root;
+  short int                  ignore_mixt_info;
 #ifdef BEAGLE
   int                                  b_inst; /*! The BEAGLE instance id associated with this tree. */
 #endif
@@ -957,7 +963,7 @@ typedef struct __Align {
   char             *name; /*! sequence name */
   int                len; /*! sequence length */
   char            *state; /*! sequence itself */
-  int           *d_state; /*! sequence itself (digits) */
+  short int     *d_state; /*! sequence itself (digits) */
   short int   *is_ambigu; /*! is_ambigu[site] = 1 if state[site] is an ambiguous character. 0 otherwise */
   short int is_duplicate;
   int                num;
@@ -1105,7 +1111,7 @@ typedef struct __Model {
   int                    augmented;
   int                           ns; /*! number of states (4 for ADN, 20 for AA) */
 
-  int                    use_m4mod; /*! Use a Makrkov modulated Markov model ? */
+  int                    use_m4mod; /*! Use a Markov modulated Markov model ? */
 
   scalar_dbl                *kappa; /*! transition/transversion rate */
   scalar_dbl               *lambda; /*! parameter used to define the ts/tv ratios in the F84 and TN93 models */
@@ -1626,6 +1632,8 @@ typedef struct __T_Rate {
   struct __T_Rate *next;
   struct __T_Rate *prev;
 
+  short int is_asynchronous;
+  short int clock_r_fixed;
 }t_rate;
 
 /*!********************************************************/
@@ -1657,6 +1665,7 @@ typedef struct __Tmcmc {
   int num_move_time_slice;
   int num_move_subtree_height;
   int num_move_kappa;
+  int num_move_rr;  
   int num_move_spr;
   int num_move_spr_weighted;
   int num_move_spr_local;
@@ -1704,6 +1713,7 @@ typedef struct __Tmcmc {
   int num_move_phyrex_disk_given_ldsk;
   int num_move_phyrex_add_remove_jump;
   int num_move_clade_change;
+  int num_move_phyrex_ldsk_tip_to_root;
 
   int nd_t_digits;
   int *monitor;
@@ -1723,6 +1733,7 @@ typedef struct __Tmcmc {
 
   int *adjust_tuning;
   int n_moves;
+  int move_idx;
   int randomize;
   int norm_freq;
   int run;
@@ -1932,7 +1943,8 @@ typedef struct __Migrep_Model{
   int                    safe_phyrex;
   phydbl             soft_bound_area;
 
-  struct __Geo_Coord            *lim; // max longitude and lattitude (the min are both set to zero)                       
+  struct __Geo_Coord            *lim_up; // max longitude and lattitude                        
+  struct __Geo_Coord            *lim_do; // min longitude and lattitude                        
 
   struct __SampArea       *samp_area;
 }t_phyrex_mod;
@@ -2021,9 +2033,6 @@ typedef struct __JSON_Array {
 /*!********************************************************/
 
 void Unroot_Tree(char **subtrees);
-void Init_Tree(t_tree *tree,int n_otu);
-void Init_Edge_Light(t_edge *b,int num);
-void Init_Node_Light(t_node *n,int num);
 void Set_Edge_Dirs(t_edge *b,t_node *a,t_node *d,t_tree *tree);
 void Init_Nexus_Format(nexcom **com);
 void Restrict_To_Coding_Position(align **data,option *io);
@@ -2064,9 +2073,6 @@ void Update_SubTree_Partial_Lk(t_edge *b_fcus,t_node *a,t_node *d,t_tree *tree);
 void Copy_Seq_Names_To_Tip_Labels(t_tree *tree,calign *data);
 calign *Copy_Cseq(calign *ori,option *io);
 int Filexists(char *filename);
-matrix *K80_dist(calign *data,phydbl g_shape);
-matrix *JC69_Dist(calign *data,t_mod *mod);
-matrix *Hamming_Dist(calign *data,t_mod *mod);
 int Is_Invar(int patt_num,int stepsize,int datatype,calign *data);
 int Is_Ambigu(char *state,int datatype,int stepsize);
 void Check_Ambiguities(calign *data,int datatype,int stepsize);
@@ -2120,11 +2126,7 @@ void Init_Eigen_Struct(eigen *this);
 phydbl Triple_Dist(t_node *a,t_tree *tree);
 phydbl Triple_Dist_Approx(t_node *a, t_edge *b, t_tree *tree);
 void Make_Symmetric(phydbl **F,int size);
-void Round_Down_Freq_Patt(phydbl **F,t_tree *tree);
-phydbl Get_Sum_Of_Cells(phydbl *F,t_tree *tree);
-void Divide_Cells(phydbl **F,phydbl div,t_tree *tree);
 void Divide_Mat_By_Vect(phydbl **F,phydbl *vect,int size);
-void Multiply_Mat_By_Vect(phydbl **F,phydbl *vect,int size);
 void Found_In_Subtree(t_node *a,t_node *d,t_node *target,int *match,t_tree *tree);
 void Get_List_Of_Target_Edges(t_node *a,t_node *d,t_edge **list,int *list_size,t_tree *tree);
 void Fix_All(t_tree *tree);
@@ -2168,13 +2170,8 @@ void Site_Diversity_Pre(t_node *a,t_node *d,t_edge *b,t_tree *tree);
 void Subtree_Union(t_node *n,t_edge *b_fcus,t_tree *tree);
 void Binary_Decomposition(int value,int *bit_vect,int size);
 void Print_Diversity_Header(FILE *fp,t_tree *tree);
-phydbl Univariate_Kernel_Density_Estimate(phydbl where,phydbl *x,int sample_size);
-phydbl Multivariate_Kernel_Density_Estimate(phydbl *where,phydbl **x,int sample_size,int vect_size);
-phydbl Var(phydbl *x,int n);
-phydbl Mean(phydbl *x,int n);
 void Best_Of_NNI_And_SPR(t_tree *tree);
 int Polint(phydbl *xa,phydbl *ya,int n,phydbl x,phydbl *y,phydbl *dy);
-void JF(t_tree *tree);
 t_tree *Dist_And_BioNJ(calign *cdata,t_mod *mod,option *io);
 void Add_BioNJ_Branch_Lengths(t_tree *tree, calign *cdata, t_mod *mod, matrix *mat);
 char *Bootstrap_From_String(char *s_tree,calign *cdata,t_mod *mod,option *io);
@@ -2188,8 +2185,6 @@ t_node *Find_Lca_Pair_Of_Nodes(t_node *n1,t_node *n2,t_tree *tree);
 t_node *Find_Lca_Clade(t_node **node_list,int node_list_size,t_tree *tree);
 int Get_List_Of_Ancestors(t_node *ref_node,t_node **list,int *size,t_tree *tree);
 int Edge_Num_To_Node_Num(int edge_num,t_tree *tree);
-void Time_To_Bl(t_tree *tree);
-void Time_To_Bl_Pre(t_node *a, t_node *d, t_edge *b, t_tree *tree);
 void Branch_Lengths_To_Rate_Lengths(t_tree *tree);
 void Branch_Lengths_To_Rate_Lengths_Pre(t_node *a,t_node *d,t_tree *tree);
 int Find_Clade(char **tax_name_list,int list_size,t_tree *tree);
@@ -2247,11 +2242,8 @@ void Joint_Proba_States_Left_Right(phydbl *Pij, phydbl *p_lk_left, phydbl *p_lk_
                    phydbl *F, int n, int site, t_tree *tree);
 void Set_Both_Sides(int yesno, t_tree *tree);
 void Set_D_States(calign *data, int datatype, int stepsize);
-void Bl_To_Time(t_tree *tree);
-void Bl_To_Time_Pre(t_node *a, t_node *d, t_tree *tree);
 void Path_Length(t_node *dep, t_node *arr, phydbl *len, t_tree *tree);
 phydbl *Dist_Btw_Tips(t_tree *tree);
-void Random_SPRs_On_Rooted_Tree(t_tree *tree);
 void Best_Root_Position_IL_Model(t_tree *tree);
 void Set_Br_Len_Var(t_edge *b, t_tree *tree);
 void Check_Br_Lens(t_tree *tree);
@@ -2330,6 +2322,10 @@ void Refactor_External(t_node *a, t_node *d, int *idx, t_tree *tree);
 void Refactor_Internal(t_node *a, t_node *d, t_edge *b, int *idx_nd, int *idx_br, t_tree *tree);
 int *Integer_To_Bit(int val, const int ns);
 char *Bit_To_Character_String(int *bit, int ns);
+t_tree *Duplicate_Tree(t_tree *ori);
+matrix *K80_dist(calign *data, phydbl g_shape);
+matrix *JC69_Dist(calign *data, t_mod *mod);
+matrix *Hamming_Dist(calign *data, t_mod *mod);
 
 
 #include "xml.h"
