@@ -130,10 +130,7 @@ t_tree *XML_Process_Base(char *xml_filename)
     }
 
   s = XML_Get_Attribute_Value(p_elem,"r.seed");
-  if(s && strlen(s)>0)
-    {
-      io->r_seed = (int)atoi(s);
-    }
+  if(s && strlen(s)>0) io->r_seed = (int)atoi(s);
 
   strcpy(io->out_file,outputfile);
   strcpy(io->out_tree_file,outputfile);
@@ -164,9 +161,17 @@ t_tree *XML_Process_Base(char *xml_filename)
 
   strcat(io->out_stats_file,".txt");
   strcat(io->out_tree_file,".txt");
- 
-  io->fp_out_tree  = Openfile(io->out_tree_file,1);
-  io->fp_out_stats = Openfile(io->out_stats_file,1);
+
+  if(XML_Search_Node_Attribute_Value("add","true",NO,root) != NULL)
+    {
+      io->fp_out_tree  = Openfile(io->out_tree_file,APPEND);
+      io->fp_out_stats = Openfile(io->out_stats_file,APPEND);
+    }
+  else
+    {
+      io->fp_out_tree  = Openfile(io->out_tree_file,WRITE);
+      io->fp_out_stats = Openfile(io->out_stats_file,WRITE);
+    }
 
   s = XML_Get_Attribute_Value(p_elem,"print.trace");
 
@@ -437,7 +442,7 @@ t_tree *XML_Process_Base(char *xml_filename)
       mixt_tree->n_pattern = io->cdata->crunch_len;
       
       /*! Remove branch lengths from mixt_tree */
-      For(i,2*mixt_tree->n_otu-1)
+      for(i=0;i<2*mixt_tree->n_otu-1;++i)
         {
           Free_Scalar_Dbl(mixt_tree->a_edges[i]->l);
           Free_Scalar_Dbl(mixt_tree->a_edges[i]->l_old);
@@ -615,8 +620,7 @@ t_tree *XML_Process_Base(char *xml_filename)
                           if(tree->n_pattern != tree->prev->n_pattern) Generic_Exit(__FILE__,__LINE__,__FUNCTION__);
                         }
                       
-                      /*! Read a component
-                       */
+                      /*! Read a component */
                       component[i] = '\0';
                       if(j != (int)strlen(list)-1) i = 0;
                                             
@@ -830,20 +834,26 @@ t_tree *XML_Process_Base(char *xml_filename)
                               
                               ds->obj = (t_ras *)iomod->ras;
                               
-                              ds->next      = (t_ds *)mCalloc(1,sizeof(t_ds));
+                              ds->next = (t_ds *)mCalloc(1,sizeof(t_ds));
                               ds = ds->next;
-                              ds->obj = (int *)(&iomod->s_opt->opt_alpha);
+                              ds->obj  = (int *)(&iomod->s_opt->opt_alpha);
                               
-                              ds->next      = (t_ds *)mCalloc(1,sizeof(t_ds));
+                              ds->next = (t_ds *)mCalloc(1,sizeof(t_ds));
                               ds = ds->next;
-                              ds->obj = (int *)(&iomod->s_opt->opt_free_mixt_rates);
+                              ds->obj  = (int *)(&iomod->s_opt->opt_free_mixt_rates);
                             }
                           else /*! Connect ras struct to an already defined one. Same for opt_alpha & opt_free_mixt_rates */
                             {
-                              if(iomod->ras != (t_ras *)parent->ds->obj) Free_RAS(iomod->ras);
-                              iomod->ras = (t_ras *)parent->ds->obj;
-                              iomod->s_opt->opt_alpha = *((int *)parent->ds->next->obj);
-                              iomod->s_opt->opt_free_mixt_rates = *((int *)parent->ds->next->next->obj);
+                              ds = parent->ds;
+                              
+                              if(iomod->ras != (t_ras *)ds->obj) Free_RAS(iomod->ras);
+                              iomod->ras = (t_ras *)ds->obj;
+
+                              ds = ds->next;
+                              iomod->s_opt->opt_alpha = *((int *)ds->obj);
+
+                              ds = ds->next;
+                              iomod->s_opt->opt_free_mixt_rates = *((int *)ds->obj);
                             }
                           
                           rate_value = XML_Get_Attribute_Value(instance,"init.value");
@@ -945,7 +955,7 @@ t_tree *XML_Process_Base(char *xml_filename)
                                   lens_size += 2*tree->n_otu-1;
                                 }
                               
-                              For(i,2*tree->n_otu-1)
+                              for(i=0;i<2*tree->n_otu-1;++i)
                                 {
                                   lens[i] = (scalar_dbl *)mCalloc(1,sizeof(scalar_dbl));
                                   Init_Scalar_Dbl(lens[i]);
@@ -975,6 +985,15 @@ t_tree *XML_Process_Base(char *xml_filename)
                                       Exit("\n");
                                     }
                                 }
+
+                              char *l_min = NULL;
+                              l_min = XML_Get_Attribute_Value(instance,"l.min");
+                              
+                              if(l_min)
+                                {
+                                  iomod->l_min = String_To_Dbl(l_min);
+                                }
+
                               
                               char *opt_bl = NULL;
                               opt_bl = XML_Get_Attribute_Value(instance,"optimise.lens");
@@ -1121,6 +1140,11 @@ t_tree *XML_Process_Base(char *xml_filename)
 
   if(!io->mod->s_opt->random_input_tree) io->mod->s_opt->n_rand_starts = 1;
 
+
+  /* int r_seed = (io->r_seed < 0)?(time(NULL)):(io->r_seed); */
+  /* srand(r_seed); */
+  /* io->r_seed = r_seed; */
+  
   Free(component);
   Free(class_num);
   
@@ -1439,7 +1463,7 @@ int XML_Parse_Element(FILE *fp, xml_node *n)
         }
 
       /* printf("\n. Setting attribute '%s=%s' to node '%s'",name,value,n->name); */
-      XML_Set_Attribute(n,name,value);
+      XML_Make_And_Set_Attribute(n,name,value);
 
       if(c == '>') break;
 
@@ -1473,7 +1497,7 @@ xml_attr *XML_Search_Attribute(xml_node *n, char *target_attr_name)
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 
-int XML_Set_Attribute(xml_node *n, char *attr_name, char *attr_value)
+int XML_Make_And_Set_Attribute(xml_node *n, char *attr_name, char *attr_value)
 {
   xml_attr *prev;
   char *s;
@@ -1506,6 +1530,51 @@ int XML_Set_Attribute(xml_node *n, char *attr_name, char *attr_value)
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 
+int XML_Set_Attribute_Value(xml_node *n, char *attr_name, char *attr_value)
+{
+  xml_attr *attr;
+  char *s;
+
+  attr = XML_Search_Attribute(n,attr_name);
+  if(attr == NULL) return(-1);
+  
+  s = To_Lower_String(attr_value);
+  strcpy(attr->value,s);
+
+  Free(s);
+  
+  return(0);
+}
+
+//////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////
+
+int XML_Add_Attribute(xml_node *n, char *attr_name, char *attr_value)
+{
+  xml_attr *attr;
+  
+  attr = n->attr;
+  while(attr->next != NULL) attr = attr->next;
+  assert(attr);
+
+  attr->next = XML_Make_Attribute(attr,attr_name,attr_value);
+  XML_Init_Attribute(attr);
+  n->n_attr++;
+
+  return(0);
+}
+
+//////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////
+
+xml_node *XML_Add_Node(xml_node *parent, char *nd_name)
+{
+  xml_node *n;
+  n = XML_Make_Node(nd_name);
+  XML_Init_Node(parent,n,nd_name);  
+  return(n);
+}
+
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 
@@ -1519,7 +1588,6 @@ int XML_Set_Node_Id(xml_node *n, char *id)
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 
-
 int XML_Set_Node_Value(xml_node *n, char *val)
 {
   XML_Make_Node_Value(n,val);
@@ -2108,7 +2176,7 @@ void XML_Write_XML_Node(FILE *fp, int *indent, xml_node *root)
   int i;
 
   s = (char *)mCalloc((*indent)+1,sizeof(char));
-  For(i,(*indent)) s[i]='\t';
+  for(i=0;i<(*indent);++i) s[i]='\t';
   s[i]='\0';
 
 
@@ -2117,32 +2185,29 @@ void XML_Write_XML_Node(FILE *fp, int *indent, xml_node *root)
   n = root;
   
   PhyML_Fprintf(fp,"<%s",n->name);
-
+  
   attr = n->attr;  
   while(attr)
     {
       PhyML_Fprintf(fp," %s=\"%s\"",attr->name,attr->value);
-      fflush(NULL);
       attr = attr->next;
     }
+  PhyML_Fprintf(fp,">");
+
+  if(n->value != NULL) XML_Write_Node_Value(fp,s,n);
 
-  
   if(n->child)
     {
       (*indent)++;
-      PhyML_Fprintf(fp,">");
       XML_Write_XML_Node(fp,indent,n->child);
-      PhyML_Fprintf(fp,"\n%s</%s>\n",s,n->name);
       (*indent)--;
     }
-  else
-    {
-      PhyML_Fprintf(fp,"/>");
-    }
 
-  if(n->next)
-    XML_Write_XML_Node(fp,indent,n->next);
-  
+  PhyML_Fprintf(fp,"\n%s</%s>",s,n->name);
+
+  PhyML_Fprintf(fp,"\n");
+
+  if(n->next) XML_Write_XML_Node(fp,indent,n->next);  
 
   Free(s);
 }
@@ -2150,6 +2215,24 @@ void XML_Write_XML_Node(FILE *fp, int *indent, xml_node *root)
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 
+void XML_Write_Node_Value(FILE *fp, char *indent, xml_node *n)
+{
+  PhyML_Fprintf(fp,"\n");
+  
+  char *tk = strtok(n->value,"\n");
+
+  do
+    {
+      PhyML_Fprintf(fp,"%s%s",indent,tk);
+      tk = strtok(NULL,"\n");
+      if(tk != NULL) PhyML_Fprintf(fp,"\n");
+    }
+  while(tk != NULL);
+
+}
+//////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////
+
 void Check_Mandatory_XML_Node(xml_node *root, char *name)
 {
   if(!XML_Search_Node_Name(name,NO,root))
@@ -2223,7 +2306,7 @@ char **XML_Read_Clade(xml_node *xnd_clade, t_tree *tree)
 void XML_Read_Calibration(xml_node *xroot, t_tree *tree)
 {
   xml_node *xnd_clade,*xnd_cal,*xnd,*xnd_dum;
-  phydbl low,up,alpha_proba_dbl;
+  phydbl low,up,alpha_proba_dbl,t,t_ref;
   t_cal *cal;
   t_clad *clade;
   char *calib_id,*clade_id,*clade_name,*alpha_proba_string;
@@ -2267,10 +2350,17 @@ void XML_Read_Calibration(xml_node *xroot, t_tree *tree)
           cal->lower = -up;
           cal->upper = -low;
           cal->is_primary = YES;
-          
+
           tree->rates->a_cal[tree->rates->n_cal] = cal;
           tree->rates->n_cal++;
-                          
+          
+          if(tree->rates->n_cal > 10 * tree->n_otu)
+            {
+              PhyML_Fprintf(stderr,"\n. There are too many clades defined that are not found in the tree..."); 
+              PhyML_Fprintf(stderr,"\n. Please remove some of them.");
+              Generic_Exit(__FILE__,__LINE__,__FUNCTION__);
+            }
+          
           xnd_dum = xnd_cal->child;
           do
             {
@@ -2307,15 +2397,6 @@ void XML_Read_Calibration(xml_node *xroot, t_tree *tree)
                           clade_size = XML_Number_Of_Taxa_In_Clade(xnd_clade->child);
 
                           clade = Make_Clade();
-
-                          if(cal->clade_list_size == 0) cal->clade_list = (t_clad **)mCalloc(1,sizeof(t_clad *));
-                          else cal->clade_list = (t_clad **)mRealloc(cal->clade_list,cal->clade_list_size+1,sizeof(t_clad *));
-                          if(cal->clade_list_size == 0) cal->alpha_proba_list = (phydbl *)mCalloc(1,sizeof(phydbl));
-                          else cal->alpha_proba_list = (phydbl *)mRealloc(cal->alpha_proba_list,cal->clade_list_size+1,sizeof(phydbl));
-                          
-                          cal->clade_list[cal->clade_list_size] = clade;
-                          cal->alpha_proba_list[cal->clade_list_size] = alpha_proba_dbl;
-                          cal->clade_list_size++;                          
                             
                           clade->n_tax = clade_size;
                           clade->tax_list = (char **)mCalloc(clade_size,sizeof(char *));
@@ -2330,13 +2411,29 @@ void XML_Read_Calibration(xml_node *xroot, t_tree *tree)
                             }
                           clade->id = (char *)mCalloc(strlen(clade_id)+1,sizeof(char));
                           strcpy(clade->id,clade_id);
-                          
-                          nd_num = Find_Clade(clade->tax_list,clade_size,tree);
-                          clade->target_nd = tree->a_nodes[nd_num];
-                          
-                          clade->tip_list = Make_Target_Tip(clade->n_tax);
-                          Init_Target_Tip(clade,tree);
 
+                          nd_num = Find_Clade(clade->tax_list,clade_size,tree);
+                          
+                          if(nd_num > -1)
+                            {
+                              clade->target_nd = tree->a_nodes[nd_num];      
+                              clade->tip_list = Make_Target_Tip(clade->n_tax);
+                              Init_Target_Tip(clade,tree);
+
+                              if(cal->clade_list_size == 0) cal->clade_list = (t_clad **)mCalloc(1,sizeof(t_clad *));
+                              else cal->clade_list = (t_clad **)mRealloc(cal->clade_list,cal->clade_list_size+1,sizeof(t_clad *));
+                              if(cal->clade_list_size == 0) cal->alpha_proba_list = (phydbl *)mCalloc(1,sizeof(phydbl));
+                              else cal->alpha_proba_list = (phydbl *)mRealloc(cal->alpha_proba_list,cal->clade_list_size+1,sizeof(phydbl));
+                              
+                              cal->clade_list[cal->clade_list_size] = clade;
+                              cal->alpha_proba_list[cal->clade_list_size] = alpha_proba_dbl;
+                              cal->clade_list_size++;
+                            }
+                          else
+                            {
+                              Free_Clade(clade);
+                            }
+                          
                           Free(xclade);
                         }
                       else
@@ -2381,11 +2478,225 @@ void XML_Read_Calibration(xml_node *xroot, t_tree *tree)
           PhyML_Printf("\n.......................................................................");
         }
     }
+
+
+  t_ref = t = -1.;
+  
+  for(i=0;i<tree->rates->n_cal;++i)
+    {
+      cal = tree->rates->a_cal[i];
+      for(j=0;j<cal->clade_list_size;j++)
+        {
+          clade = cal->clade_list[j];
+          if(clade->target_nd->tax == YES)
+            {
+              if(t_ref < -.5)
+                {
+                  t_ref = Uni()*(cal->upper - cal->lower) + cal->lower;
+                  t_ref = fabs(t_ref);
+                }
+              else
+                {
+                  t = Uni()*(cal->upper - cal->lower) + cal->lower;
+                  t = fabs(t);
+
+                  if(Are_Equal(t,t_ref,1.E-10) == NO)
+                    {
+                      tree->rates->is_asynchronous = YES;
+                      break;
+                    }
+                }                    
+            }
+        }
+    }
+  
+  PhyML_Printf("\n\n");
+  PhyML_Printf("\n. Is asynchronous: %s",tree->rates->is_asynchronous ? "yes" : "no");
 }
 
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 
+void XML_Update_XML_Struct_Given_Model_Params(t_tree *tree)
+{
+  xml_node *parent,*child,*x;
+  char *s,*val;
+  t_ds *ds;
+  phydbl v;
+  
+  val = (char *)mCalloc(T_MAX_LINE,sizeof(char));
+  
+  parent = XML_Search_Node_Name("ratematrices",YES,tree->xml_root);
+  if(parent != NULL)
+    {
+      child = parent->child;
+      
+      assert(child != NULL);
+
+      do
+        {
+          ds = child->ds;
+
+          assert(ds);
+                    
+          x = XML_Search_Node_Name("rr",YES,child); 
+
+          if(x != NULL)
+            {
+              s = XML_Get_Attribute_Value(x,"AC");
+              if(s != NULL)
+                {
+                  sprintf(val,"%f",((t_rmat *)(ds->obj))->rr->v[0]);
+                  XML_Set_Attribute_Value(x,"AC",val);
+                }
+
+              s = XML_Get_Attribute_Value(x,"AG");
+              if(s != NULL)
+                {
+                  sprintf(val,"%f",((t_rmat *)(ds->obj))->rr->v[1]);
+                  XML_Set_Attribute_Value(x,"AC",val);
+                }
+
+              s = XML_Get_Attribute_Value(x,"AT");
+              if(s != NULL)
+                {
+                  sprintf(val,"%f",((t_rmat *)(ds->obj))->rr->v[2]);
+                  XML_Set_Attribute_Value(x,"AT",val);
+                }
+
+              s = XML_Get_Attribute_Value(x,"CG");
+              if(s != NULL)
+                {
+                  sprintf(val,"%f",((t_rmat *)(ds->obj))->rr->v[3]);
+                  XML_Set_Attribute_Value(x,"CG",val);
+                }
+
+              s = XML_Get_Attribute_Value(x,"CT");
+              if(s != NULL)
+                {
+                  sprintf(val,"%f",((t_rmat *)(ds->obj))->rr->v[4]);
+                  XML_Set_Attribute_Value(x,"CT",val);
+                }
+            }
+
+
+          ds = ds->next;
+          assert(ds);
+          
+          s = XML_Get_Attribute_Value(child,"tstv");
+          if(s != NULL)
+            {
+              sprintf(val,"%f",((scalar_dbl *)(ds->obj))->v);
+              XML_Set_Attribute_Value(child,"tstv",val);
+            }
+          
+          child = child->next;
+        }
+      while(child);
+    }
+
+
+  parent = XML_Search_Node_Name("siterates",YES,tree->xml_root);
+
+  if(parent != NULL)
+    {
+      child = parent->child;      
+      assert(child != NULL);
+
+      int class = 0;
+      do
+        {
+          s = XML_Get_Attribute_Value(child,"init.value");
+          if(s != NULL)
+            {
+              v = atof(s);
+              if(Are_Equal(v,0.0,1E-20) == NO)
+                {
+                  sprintf(val,"%f",((t_ras *)(parent->ds->obj))->gamma_rr->v[class]);
+                  XML_Set_Attribute_Value(child,"init.value",val);
+                  class++;                  
+                }
+            }
+        
+          child = child->next;          
+        }
+      while(child);
+
+
+      child = XML_Search_Node_Name("weights",YES,parent);
+      assert(child != NULL);
+      s = XML_Get_Attribute_Value(child,"family");
+      assert(s != NULL);
+      if(!strcmp(s,"gamma"))
+        {
+          s = XML_Get_Attribute_Value(child,"alpha");
+          if(s != NULL)
+            {
+              sprintf(val,"%f",((t_ras *)(parent->ds->obj))->alpha->v);
+              XML_Set_Attribute_Value(child,"alpha",val);
+            }
+        }
+      else if(!strcmp(s,"gamma+inv"))
+        {
+          s = XML_Get_Attribute_Value(child,"alpha");
+          if(s != NULL)
+            {
+              sprintf(val,"%f",((t_ras *)(parent->ds->obj))->alpha->v);
+              XML_Set_Attribute_Value(child,"alpha",val);
+              
+              sprintf(val,"%f",((t_ras *)(parent->ds->obj))->pinvar->v);
+              XML_Set_Attribute_Value(child,"pinv",val);
+            }
+        }
+
+      
+      child = XML_Search_Node_Name("weights",YES,parent);
+      child = child->child;
+      assert(child);
+
+      
+      class = 0;
+      do
+        {
+          // Find the rate class that this weight instance points to
+          s = XML_Get_Attribute_Value(child,"appliesto");
+          assert(s);
+          x = XML_Search_Node_Attribute_Value("id",s,YES,parent);
+          assert(x);
+          
+          s = XML_Get_Attribute_Value(x,"init.value");
+          if(s != NULL)
+            {
+              v = atof(s);
+              if(Are_Equal(v,0.0,1E-20) == NO)
+                {
+                  sprintf(val,"%f",((t_ras *)(parent->ds->obj))->gamma_r_proba->v[class]);
+                  XML_Set_Attribute_Value(child,"value",val);
+                  class++;
+                }
+              else
+                {
+                  sprintf(val,"%f",0.0);
+                  XML_Set_Attribute_Value(child,"value",val);                  
+                }
+            }
+          child = child->next;
+        }
+      while(child);
+      
+      
+    }
+
+
+
+
+
+
+}
+
+
+
+
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////
